NativeCodeError class

The class for errors occurred in the Native code of the library

Implemented types

Constructors

NativeCodeError(NSError nsError)

Properties

code int
final
description String
final
domain String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited