flutter_blue_ultra_accessory_setup library
Classes
- FlutterAccessorySetup
- The main class of the library that provides service functionality Use it to activate the session and find and configure devices
Extensions
- ASAccessoryDartExtension on ASAccessory
- Exposing native properties as Dart types
- ASAccessoryEventDartExtension on ASAccessoryEvent
- Exposing native properties as Dart types
Exceptions / Errors
- FlutterAccessorySetupError
- The class for errors occurred in the Dart code of the library
- NativeCodeError
- The class for errors occurred in the Native code of the library