Accessory class
A serializable view of ASAccessory. The real native object is retained on
the host side, keyed by bluetoothIdentifier.
Constructors
- Accessory({String? bluetoothIdentifier, required String displayName, required AccessoryState state, String? ssid})
Properties
- bluetoothIdentifier ↔ String?
-
getter/setter pair
- displayName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssid ↔ String?
-
getter/setter pair
- state ↔ AccessoryState
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override